@@ -124,9 +124,11 @@ def get_first_file(path: Path) -> Path:  # pragma: no cover
 
 def generate(
     input_: Union[Path, str],
-    input_file_type: InputFileType,
-    output: Optional[Path],
-    target_python_version: PythonVersion,
+    *,
+    input_filename: Optional[str] = None,
+    input_file_type: InputFileType = InputFileType.Auto,
+    output: Optional[Path] = None,
+    target_python_version: PythonVersion = PythonVersion.PY_37,
     base_class: str = DEFAULT_BASE_CLASS,
     custom_template_dir: Optional[Path] = None,
     extra_template_data: Optional[DefaultDict[str, Dict[str, Any]]] = None,
@@ -137,7 +139,8 @@ def generate(
     aliases: Optional[Mapping[str, str]] = None,
     disable_timestamp: bool = False,
     allow_population_by_field_name: bool = False,
-    use_default_on_required_field: bool = False,
+    apply_default_values_for_required_fields: bool = False,
+    force_optional_for_required_fields: bool = False,
 ) -> None:
     input_text: Optional[str] = None
     if input_file_type == InputFileType.Auto:
@@ -191,15 +194,17 @@ def generate(
         strip_default_none=strip_default_none,
         aliases=aliases,
         allow_population_by_field_name=allow_population_by_field_name,
-        use_default_on_required_field=use_default_on_required_field,
+        apply_default_values_for_required_fields=apply_default_values_for_required_fields,
+        force_optional_for_required_fields=force_optional_for_required_fields,
     )
 
     with chdir(output):
         results = parser.parse()
-    if isinstance(input_, str):
-        input_filename = '<stdin>'
-    else:
-        input_filename = input_.name
+    if not input_filename:
+        if isinstance(input_, str):
+            input_filename = '<stdin>'
+        else:
+            input_filename = input_.name
     if isinstance(results, str):
 
         modules = {output: (results, input_filename)}
