@@ -34,7 +34,12 @@ def get_model_by_path(schema: Dict[str, Any], keys: List[str]) -> Dict[str, Any]
 
 
 json_schema_data_formats: Dict[str, Dict[str, Types]] = {
-    'integer': {'int32': Types.int32, 'int64': Types.int64, 'default': Types.integer},
+    'integer': {
+        'int32': Types.int32,
+        'int64': Types.int64,
+        'default': Types.integer,
+        'unix-time': Types.int64,
+    },
     'number': {
         'float': Types.float,
         'double': Types.double,
@@ -186,7 +191,8 @@ class JsonSchemaParser(Parser):
         strip_default_none: bool = False,
         aliases: Optional[Mapping[str, str]] = None,
         allow_population_by_field_name: bool = False,
-        use_default_on_required_field: bool = False,
+        apply_default_values_for_required_fields: bool = False,
+        force_optional_for_required_fields: bool = False,
     ):
         super().__init__(
             source=source,
@@ -205,7 +211,8 @@ class JsonSchemaParser(Parser):
             strip_default_none=strip_default_none,
             aliases=aliases,
             allow_population_by_field_name=allow_population_by_field_name,
-            use_default_on_required_field=use_default_on_required_field,
+            apply_default_values_for_required_fields=apply_default_values_for_required_fields,
+            force_optional_for_required_fields=force_optional_for_required_fields,
         )
 
         self.remote_object_cache: Dict[str, Dict[str, Any]] = {}
@@ -414,7 +421,9 @@ class JsonSchemaParser(Parser):
                 field_type = self.get_data_type(field)
                 if self.field_constraints:
                     constraints = field.dict()
-            if self.use_default_on_required_field and field.has_default:
+            if self.force_optional_for_required_fields or (
+                self.apply_default_values_for_required_fields and field.has_default
+            ):
                 required: bool = False
             else:
                 required = original_field_name in requires
@@ -515,6 +524,12 @@ class JsonSchemaParser(Parser):
                 item_obj_data_types.append(array_field.data_type)
             else:
                 item_obj_data_types.append(self.get_data_type(item))
+        if self.force_optional_for_required_fields:
+            required: bool = False
+        else:
+            required = not obj.nullable and not (
+                obj.has_default and self.apply_default_values_for_required_fields
+            )
         field = self.data_model_field_type(
             data_type=self.data_type(data_types=item_obj_data_types, is_list=True,),
             example=obj.example,
@@ -522,8 +537,7 @@ class JsonSchemaParser(Parser):
             default=obj.default,
             description=obj.description,
             title=obj.title,
-            required=not obj.nullable
-            and not (obj.has_default and self.use_default_on_required_field),
+            required=required,
             constraints=obj.dict(),
         )
         return field
@@ -555,7 +569,12 @@ class JsonSchemaParser(Parser):
             data_type = self.get_ref_data_type(obj.ref)
         else:
             data_type = self.data_type_manager.get_data_type(Types.any)
-
+        if self.force_optional_for_required_fields:
+            required: bool = False
+        else:
+            required = not obj.nullable and not (
+                obj.has_default and self.apply_default_values_for_required_fields
+            )
         data_model_root_type = self.data_model_root_type(
             name,
             [
@@ -565,8 +584,7 @@ class JsonSchemaParser(Parser):
                     example=obj.example,
                     examples=obj.examples,
                     default=obj.default,
-                    required=not obj.nullable
-                    and not (obj.has_default and self.use_default_on_required_field),
+                    required=required,
                     constraints=obj.dict() if self.field_constraints else {},
                 )
             ],
